@@ -1,7 +1,7 @@
-use std::{error, fmt};
+use core::fmt;
 
 /// Type alias to use this library's [`Error`] type in a `Result`.
-pub type Result<T> = std::result::Result<T, Error>;
+pub type Result<T> = core::result::Result<T, Error>;
 
 /// Error types
 #[derive(PartialEq, Eq, Clone, Debug)]
@@ -21,7 +21,8 @@ impl fmt::Display for Error {
     }
 }
 
-impl error::Error for Error {}
+#[cfg(feature = "std")]
+impl std::error::Error for Error {}
 
 impl From<base_x::DecodeError> for Error {
     fn from(_: base_x::DecodeError) -> Self {
